@@ -1,10 +1,8 @@
 package Javonet::Core::Handler::CommandHandler::InvokeInstanceMethodHandler;
-use aliased 'Javonet::Core::Handler::PerlHandler' => 'PerlHandler';
 use strict;
 use warnings FATAL => 'all';
-use Moose;
 use lib 'lib';
-use lib 'data_seed';
+use Moose;
 use Nice::Try;
 use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
