@@ -2,6 +2,8 @@ package Javonet::Sdk::Core::RuntimeLib;
 use warnings;
 use strict;
 use Moose;
+use Exporter qw(import);
+our @EXPORT = qw(get_runtime);
 
 my %runtimes = (
     'Clr'       => 0,
@@ -12,7 +14,9 @@ my %runtimes = (
     'Python'    => 5,
     'Ruby'      => 6,
     'Nodejs'    => 7,
-    'Cpp'       => 8
+    'Cpp'       => 8,
+    'Php'       => 9,
+    'Python2'   => 10
 );
 
 sub get_runtime {
